/*
 * ConnectionAdapter.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.event;

/**
 * The adapter which receives connection events. 
 * The methods in this class are empty; this class is provided 
 * as a convenience for easily creating listeners by extending this class 
 * and overriding only the methods of interest.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 */
public abstract class ConnectionAdapter
  implements ConnectionListener
{

  /**
   * Invoked when a Store/Folder/Transport is opened.
   */
  public void opened(ConnectionEvent e)
  {
  }

  /**
   * Invoked when a Store is disconnected.
   * Note that a folder cannot be disconnected, so a folder will not fire 
   * this event.
   */
  public void disconnected(ConnectionEvent e)
  {
  }

  /**
   * Invoked when a Store/Folder/Transport is closed.
   */
  public void closed(ConnectionEvent e)
  {
  }

}
